pub trait RegisterInfo: Sized {
type RegType: Register<InfoType = Self>;
// Required methods
fn parent(&self) -> Option<Self::RegType>;
fn size(&self) -> usize;
fn offset(&self) -> usize;
fn implicit_extend(&self) -> ImplicitRegisterExtend;
}Expand description
Information about a register.
Required Associated Types
Required Methods
Sourcefn parent(&self) -> Option<Self::RegType>
fn parent(&self) -> Option<Self::RegType>
The register that this register is an alias of.
Example (x86-64)
The register rax is a parent of the register eax.
Sourcefn offset(&self) -> usize
fn offset(&self) -> usize
Offset of the register in bytes from the start of the containing RegisterInfo::parent.
Sourcefn implicit_extend(&self) -> ImplicitRegisterExtend
fn implicit_extend(&self) -> ImplicitRegisterExtend
Used when this register aliases a logical register to determine what happens to the upper bits.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.